# Copyright 2016 Paul Hänsch
#
# This file is part of Confetti.
# 
# Confetti is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Confetti is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with Confetti.  If not, see <http://www.gnu.org/licenses/>. 

t_session_note(){
  session_n="$1"
  note_n="$2"
  
  color=session${session_n}_note${note_n}_color
  unset c0 c1 c2 c3 c4 c5 c6 c7
  
  case "$tpy[$color]" in
    \#888) c0=checked;;
    \#00A) c1=checked;;
    \#0A0) c2=checked;;
    \#0AA) c3=checked;;
    \#A00) c4=checked;;
    \#A0A) c5=checked;;
    \#AA0) c6=checked;;
    *)    c7=checked;;
  esac

if [ "$note_n" -eq 1 -o -n "${tpy[session${session_n}_note${note_n}]}" ]; then
  printf '<input class="trailbtn" type="checkbox" checked="checked">'
else
  printf '<input class="trailbtn" type="checkbox">'
fi
cat <<EOF
  <fieldset class="note trailbox">
    <input class=color type=radio name="$color" value="#888" id=${color}_000 $c0><label for=${color}_000></label>
    <input class=color type=radio name="$color" value="#00A" id=${color}_001 $c1><label for=${color}_001></label>
    <input class=color type=radio name="$color" value="#0A0" id=${color}_010 $c2><label for=${color}_010></label>
    <input class=color type=radio name="$color" value="#0AA" id=${color}_011 $c3><label for=${color}_011></label>
    <input class=color type=radio name="$color" value="#A00" id=${color}_100 $c4><label for=${color}_100></label>
    <input class=color type=radio name="$color" value="#A0A" id=${color}_101 $c5><label for=${color}_101></label>
    <input class=color type=radio name="$color" value="#AA0" id=${color}_110 $c6><label for=${color}_110></label>
    <input class=color type=radio name="$color" value="#FFF" id=${color}_111 $c7><label for=${color}_111></label>
    <textarea name="session${session_n}_note${note_n}">${tpy[session${session_n}_note${note_n}]}</textarea>
  </fieldset>
EOF
}

t_session(){
  session_n="$1"

  sid=session${session_n}

  if [ "$tpy[${sid}_sigset]" = pos ]; then
    sigcheck=checked
  else
    unset sigcheck
  fi

cat <<EOF
  <input type=hidden name=$sid value=exists>
  <input class="tab" type="checkbox" id=${sid}_open name="${sid}_open" value="checked" ${tpy[${sid}_open]}>
  <label class="tab" for="${sid}_open">
    <span class=no>${session_n}.</span><!--
 --><span class=date>${tpy[${sid}_date]}</span><!--
 --><input class="date" name="${sid}_date" value="${tpy[${sid}_date]}" placeholder="$(l10n date)"><!--
 --><span class=therapist>${tpy[${sid}_therapist]}</span><!--
 --><input class="therapist" name="${sid}_therapist" value="${tpy[${sid}_therapist]}" placeholder="$(l10n therapist)"><!--
 --><span class=signature><input type="checkbox" name="${sid}_sigset" value="pos" $sigcheck></span>
  </label>
  <div class=tab>
    <img class="dotmark ov" src="/therapies/${id%.tpy}_${sid}.png" alt="">
    $( for n in {1..10}; do t_session_note $session_n $n; done )

    <button class=delete type=submit name=delete_session value=${session_n}>$(l10n delete_session)</button>
  </div>
EOF
}

therapy_sessions(){
  n=1; while [ -n "${tpy[session${n}]}" ]; do
    t_session $n
    n=$(($n+1))
  done

  sid=session$n

cat <<EOF
  <fieldset class="tab">
    <button class=no type=submit name=new_session value=$sid>+</button><!--
 --><input class=date name=${sid}_date value="" placeholder="$(l10n date)" /><!--
 --><input class=therapist name=${sid}_therapist value="" placeholder="$(l10n therapist)" /><!--
 --><span class=signature><span></span>
    <input type=hidden name="${sid}_note1" value="">
  </fieldset>
EOF
}

unset c0 c1 c2 c3 c4 c5 c6 c7
case "$tpy[color]" in
  \#00A) c1="checked";;
  \#0A0) c2="checked";;
  \#0AA) c3="checked";;
  \#A00) c4="checked";;
  \#A0A) c5="checked";;
  \#AA0) c6="checked";;
  \#FFF) c7="checked";;
      *) c0="checked";;
esac

cat <<EOF
<h1>$(l10n therapy)</h1>

<div class="patient">
  <h2>$client_name</h2>
  <a href="?p=prescriptions&amp;client=${id%%.*}.vcf">&lt; $(l10n prescriptionlist)</a>
</div>

<div class="prescription">
  <h2>$(l10n therapy_prescription)</h2>
  <span class="insurance">${mpx[insurance]}</span>
  <span class="date"><label>$(l10n date):</label>${mpx[date]}</span>

  <label class="checkbox ${mpx[prescreviewed]:+checked}" for="prescreviewed">
    $([ -n "${mpx[prescreviewed]}" ] && printf %s "$(l10n prescreviewed)" \
                                     || printf %s "$(l10n prescreview)" )
  </label>

       ${mpx[prescno]:+<span class="prescno">$(l10n presc${mpx[prescno]})</span>}
  ${mpx[grouptherapy]:+<span class="catalogue">$(l10n grouptherapy)</span>}
     ${mpx[housecall]:+<span class="catalogue">$(l10n housecall)</span>}
        ${mpx[report]:+<span class="catalogue">$(l10n report)</span>}

  <ul>$(for n in '' {0..10}; do
    [ -n "${mpx[remidy$n]}" ] && \
    printf '<li>%s %s %s</li>' "${mpx[quantity$n]}" \
                               "${mpx[remidy$n]}" \
                               "${mpx[quantity_weekly$n]:+($mpx[quantity_weekly$n] $(l10n weekly))}"
  done)</ul>

  ${mpx[indicator]:+<span class="indicator"><label>$(l10n indicator):</label>${mpx[indicator]}</span>}
      ${mpx[icd10]:+<span class="icd10">    <label>$(l10n icd10):</label>${mpx[icd10]}</span>}

  ${mpx[addcontrib]:+
  <label class='checkbox ${mpx[contribconfirm]:+checked}' for="addcontrib">
    $([ -n "${mpx[contribconfirm]}" ] && printf %s "$(l10n contribconfirm)" ${mpx[contribconfirm]} \
                                      || printf %s "$(l10n addcontrib)" )
  </label>
  }

  <input class="tab" type="checkbox" id="indicator_reading">
  <label class="tab" for="indicator_reading">$(l10n indicator_reading)</label>
  <div class="tab">${mpx[indicator_reading]}</div>
</div>

<form id="report" method="POST" action="?action=update_therapy">
  <input type="hidden" name="id" value="${id}">

  <input class="stickynote" type="checkbox" name="c_stickynote" id="show_stickynote">
  <fieldset class="stickynote">
    <label for="show_stickynote">$(l10n notes)</label>
    <textarea name="stickynote">${tpy[stickynote]}</textarea>
    <button type=submit>$(l10n save)</button>
  </fieldset>

  <!--input class="tab" type="checkbox" id="lookout">
  <label class="tab" for="lookout">$(l10n indicator_reading)</label>
  <div class="tab"><textarea name="lookout">${mpx[lookout]}</textarea -->

  <label class="tab heading">
    <span class=no>$(l10n number)</span><!--
 --><span class=date>$(l10n date)</span><!--
 --><span class=therapist>$(l10n therapist)</span><!--
 --><span class=signature>$(l10n signature)</span>
  </label>
EOF

therapy_sessions

cat <<EOF
  <fieldset class=color>
    <input class=color type=radio name=color onclick="javascript:setcol('#000')" value="#000" id=c000 $c0><label for=c000></label>
    <input class=color type=radio name=color onclick="javascript:setcol('#00A')" value="#00A" id=c001 $c1><label for=c001></label>
    <input class=color type=radio name=color onclick="javascript:setcol('#0A0')" value="#0A0" id=c010 $c2><label for=c010></label>
    <input class=color type=radio name=color onclick="javascript:setcol('#0AA')" value="#0AA" id=c011 $c3><label for=c011></label>
    <input class=color type=radio name=color onclick="javascript:setcol('#A00')" value="#A00" id=c100 $c4><label for=c100></label>
    <input class=color type=radio name=color onclick="javascript:setcol('#A0A')" value="#A0A" id=c101 $c5><label for=c101></label>
    <input class=color type=radio name=color onclick="javascript:setcol('#AA0')" value="#AA0" id=c110 $c6><label for=c110></label>
    <input class=color type=radio name=color onclick="javascript:setcol('#FFF')" value="#FFF" id=c111 $c7><label for=c111></label>
  </fieldset>
  <img class="dotmark bg" src="?static=therapy_background.png" alt="WARNING: Background Image not available!">
  <canvas id="canvas" class="dotmark ov" width="${bg_dim%x*}" height="${bg_dim#*x}"></canvas>

  <input type=hidden id=image_serialize name=imagedata value="">

  <button type="submit">$(l10n save)</button>
</form>

<span id="jsdebug" style="display: none; position: fixed; right:0; bottom:0">Debug</span>

<script type="text/javascript" src="?static=therapy_draw.js"></script>
EOF
# vi:set filetype=html:
